/*
 *    Copyright 2009-2010 The Rocoto Team
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 */
package com.googlecode.rocoto.configuration.internal;

import java.util.Map.Entry;

/**
 * A simple {@code Entry<String, String>} implementation.
 *
 * @author Simone Tripodi
 * @since 4.0
 * @version $Id: KeyValue.java 572 2010-10-24 10:52:30Z simonetripodi $
 */
public final class KeyValue implements Entry<String, String> {

    /**
     * The entry key.
     */
    private final String key;

    /**
     * The entry value.
     */
    private final String value;

    /**
     * Creates a new {@code Entry<String, String>}.
     *
     * @param key the entry key.
     * @param value the entry value.
     */
    public KeyValue(String key, String value) {
        this.key = key;
        this.value = value;
    }

    /**
     * {@inheritDoc}
     */
    public String getKey() {
        return this.key;
    }

    /**
     * {@inheritDoc}
     */
    public String getValue() {
        return this.value;
    }

    /**
     * {@inheritDoc}
     */
    public String setValue(String value) {
        // not needed in this version
        return null;
    }

}
