/*
 *    Copyright 2009-2010 The Rocoto Team
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 */
package com.googlecode.rocoto.configuration.resolver;

import com.google.inject.Injector;

/**
 * Simple text appender, just append a text fragment in the given buffer.
 *
 * @author Simone Tripodi
 * @since 4.0
 * @version $Id: TextAppender.java 575 2010-10-24 13:13:00Z simonetripodi $
 */
final class TextAppender implements Appender {

    /**
     * The text fragment to append to the given buffer.
     */
    private final String textFragment;

    /**
     * Create a new text appender.
     *
     * @param textFragment the text fragment to append to the given buffer.
     */
    public TextAppender(final String textFragment) {
        this.textFragment = textFragment;
    }

    /**
     * {@inheritDoc}
     */
    public void append(StringBuilder buffer, Injector injector) {
        buffer.append(this.textFragment);
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public String toString() {
        return this.textFragment;
    }

}
